@@ -9,7 +9,14 @@ from ramodels.mo._shared import UUIDBase
 
 class Detail(UUIDBase):
     type: Literal[
-        "address", "association", "engagement", "org_unit", "manager", "it", "role"
+        "address",
+        "association",
+        "engagement",
+        "org_unit",
+        "manager",
+        "it",
+        "role",
+        "kle",
     ] = Field(
         description="Name of the type of detail we wish to terminate. "
         "Must be a valid lora role_type like:  'address', "
@@ -18,7 +25,6 @@ class Detail(UUIDBase):
 
 
 class DetailTermination(Detail):
-
     validity: dict | None = Field(
         description="MO unit validity, determining in what date-interval "
         "a unit is available."
